@@ -17,11 +17,15 @@ do_EnrichmentHeatmap <- function(sample,
                                  features.order = NULL,
                                  groups.order = NULL,
                                  cluster = TRUE,
-                                 scale_scores = TRUE,
+                                 scale_scores = FALSE,
                                  assay = NULL,
                                  slot = NULL,
                                  reduction = NULL,
                                  group.by = NULL,
+                                 values.show = FALSE,
+                                 values.threshold = NULL,
+                                 values.size = 3,
+                                 values.round = 1,
                                  verbose = FALSE,
                                  na.value = "grey75",
                                  legend.position = "bottom",
@@ -79,7 +83,8 @@ do_EnrichmentHeatmap <- function(sample,
                        "plot_cell_borders" = plot_cell_borders,
                        "flip" = flip,
                        "cluster" = cluster,
-                       "scale_scores" = scale_scores)
+                       "scale_scores" = scale_scores,
+                       "values.show" = values.show)
   check_type(parameters = logical_list, required_type = "logical", test_function = is.logical)
   # Check numeric parameters.
   numeric_list <- list("viridis.direction" = viridis.direction,
@@ -99,7 +104,10 @@ do_EnrichmentHeatmap <- function(sample,
                        "max.cutoff" = max.cutoff,
                        "number.breaks" = number.breaks,
                        "sequential.direction" = sequential.direction,
-                       "diverging.direction" = diverging.direction)
+                       "diverging.direction" = diverging.direction,
+                       "values.threshold" = values.threshold,
+                       "values.size" = values.size,
+                       "values.round" = values.round)
   check_type(parameters = numeric_list, required_type = "numeric", test_function = is.numeric)
   # Check character parameters.
   character_list <- list("input_gene_list" = input_gene_list,
@@ -193,7 +201,7 @@ do_EnrichmentHeatmap <- function(sample,
   }
   
   if (is.null(assay)){assay <- check_and_set_assay(sample)$assay}
-  if (is.null(slot)){slot <- check_and_set_slot(slot)}
+  slot <- if(is.null(slot)){"data"} else {slot}
   
   if (is.character(input_gene_list)){
     stop(paste0(add_cross(),
@@ -216,12 +224,10 @@ do_EnrichmentHeatmap <- function(sample,
   }
   
   if (is.null(legend.title)){
-    if (flavor == "AUCell") {
-      legend.title <- "AUC"
-    } else if (flavor == "UCell"){
-      legend.title <- "UCell score"
+    if (flavor == "UCell"){
+      legend.title <- ifelse(isTRUE(scale_scores), "UCell score | Scaled", "UCell score")
     } else if (flavor == "Seurat"){
-      legend.title <- "Enrichment"
+      legend.title <- ifelse(isTRUE(scale_scores), "Enrichment | Scaled", "Enrichment")
     }
   }
   
@@ -265,6 +271,14 @@ do_EnrichmentHeatmap <- function(sample,
     # nocov end
   }
   
+  if (base::isTRUE(values.show)){
+    assertthat::assert_that(is.numeric(values.threshold),
+                            msg = paste0(add_cross(), crayon_body("Please provide a value to "),
+                                         crayon_key("values.threshold"),
+                                         crayon_body(" when setting "),
+                                         crayon_key("values.show = TRUE"),
+                                         crayon_body(".")))
+  }
 
   # Compute the enrichment scores.
   sample <- compute_enrichment_scores(sample = sample,
@@ -277,7 +291,8 @@ do_EnrichmentHeatmap <- function(sample,
                                       storeRanks = storeRanks,
                                       # nocov start
                                       assay = if (flavor == "UCell"){NULL} else {assay},
-                                      slot = if (flavor == "Seurat"){NULL} else {slot})
+                                      slot = if (flavor == "Seurat"){NULL} else {slot},
+                                      norm_data = scale_scores)
                                       # nocov end
   out.list <- list()
   
@@ -290,12 +305,8 @@ do_EnrichmentHeatmap <- function(sample,
   group.by <- out[["group.by"]]
 
   matrix.list <- list()
+  names.use <- names(input_list)
   
-  if (base::isFALSE(scale_scores)){
-    names.use <- names(input_list)
-  } else {
-    names.use <- unname(vapply(names(input_list), function(x){paste0(x, "_scaled")}, FUN.VALUE = character(1)))
-  }
   for (group in group.by){
     suppressMessages({
       sample$group.by <- sample@meta.data[, group]
@@ -429,7 +440,25 @@ do_EnrichmentHeatmap <- function(sample,
                                                 y = if(base::isFALSE(flip)){.data$group.by} else {.data$gene_list},
                                                 fill = .data$mean)) +
          # nocov end
-         ggplot2::geom_tile(color = grid.color, linewidth = 0.5) +
+         ggplot2::geom_tile(color = grid.color, linewidth = 0.5)
+    
+    
+    if (base::isTRUE(values.show)){
+      if (base::isTRUE(enforce_symmetry)){
+        p <- p + 
+          ggplot2::geom_text(ggplot2::aes(label = round(.data$mean, values.round), 
+                                          color = ifelse(abs(.data$mean) > values.threshold, "white", "black")), 
+                             size = values.size)
+      } else {
+        p <- p + 
+          ggplot2::geom_text(ggplot2::aes(label = round(.data$mean, values.round), 
+                                          color = ifelse(.data$mean > values.threshold, "white", "black")), 
+                             size = values.size)
+      }
+      p <- p + ggplot2::scale_color_identity()
+    }
+    
+    p <- p +
          ggplot2::scale_y_discrete(expand = c(0, 0)) +
          ggplot2::scale_x_discrete(expand = c(0, 0),
                                    position = "top") +
