@@ -17,6 +17,10 @@ do_ExpressionHeatmap <- function(sample,
                                  features.order = NULL,
                                  groups.order = NULL,
                                  slot = "data",
+                                 values.show = FALSE,
+                                 values.threshold = NULL,
+                                 values.size = 3,
+                                 values.round = 1,
                                  legend.title = "Avg. Expression",
                                  na.value = "grey75",
                                  legend.position = "bottom",
@@ -63,7 +67,8 @@ do_ExpressionHeatmap <- function(sample,
   logical_list <- list("enforce_symmetry" = enforce_symmetry,
                        "use_viridis" = use_viridis,
                        "flip" = flip,
-                       "cluster" = cluster)
+                       "cluster" = cluster,
+                       "values.show" = values.show)
   check_type(parameters = logical_list, required_type = "logical", test_function = is.logical)
   # Check numeric parameters.
   numeric_list <- list("axis.text.x.angle" = axis.text.x.angle,
@@ -77,7 +82,10 @@ do_ExpressionHeatmap <- function(sample,
                        "number.breaks" = number.breaks,
                        "viridis.direction" = viridis.direction,
                        "sequential.direction" = sequential.direction,
-                       "diverging.direction" = diverging.direction)
+                       "diverging.direction" = diverging.direction,
+                       "values.threshold" = values.threshold,
+                       "values.size" = values.size,
+                       "values.round" = values.round)
   check_type(parameters = numeric_list, required_type = "numeric", test_function = is.numeric)
 
   # Check character parameters.
@@ -187,7 +195,16 @@ do_ExpressionHeatmap <- function(sample,
                                        crayon_body(" are present in the "),
                                        crayon_key("sample"),
                                        crayon_body(".")))
-
+  
+  if (base::isTRUE(values.show)){
+    assertthat::assert_that(is.numeric(values.threshold),
+                            msg = paste0(add_cross(), crayon_body("Please provide a value to "),
+                                         crayon_key("values.threshold"),
+                                         crayon_body(" when setting "),
+                                         crayon_key("values.show = TRUE"),
+                                         crayon_body(".")))
+  }
+  
   matrix.list <- list()
   for (group in group.by){
     # Extract activities from object as a long dataframe
@@ -323,7 +340,24 @@ do_ExpressionHeatmap <- function(sample,
                                                 y = if (base::isFALSE(flip)){.data$group.by} else {.data$gene},
                                                 fill = .data$mean)) +
          # nocov end
-         ggplot2::geom_tile(color = grid.color, linewidth = 0.5) +
+         ggplot2::geom_tile(color = grid.color, linewidth = 0.5)
+    
+    if (base::isTRUE(values.show)){
+      if (base::isTRUE(enforce_symmetry)){
+        p <- p + 
+          ggplot2::geom_text(ggplot2::aes(label = round(.data$mean, values.round), 
+                                          color = ifelse(abs(.data$mean) > values.threshold, "white", "black")), 
+                             size = values.size)
+      } else {
+        p <- p + 
+          ggplot2::geom_text(ggplot2::aes(label = round(.data$mean, values.round), 
+                                          color = ifelse(.data$mean > values.threshold, "white", "black")), 
+                             size = values.size)
+      }
+      p <- p + ggplot2::scale_color_identity()
+    }
+    
+    p <- p + 
          ggplot2::scale_y_discrete(expand = c(0, 0)) +
          ggplot2::scale_x_discrete(expand = c(0, 0),
                                    position = "top") +
