@@ -28,7 +28,7 @@
     p <- SCpubr::do_DimPlot(sample,
                             idents.highlight = c("1", "3"))
 
-  } else if (isFALSE(value)){
+  } else if (base::isFALSE(value)){
     message("This function can not be used without its suggested packages.")
     message("Check out which ones are needed using `SCpubr::state_dependencies()`.")
   }
