@@ -15,12 +15,16 @@ if (requireNamespace("dplyr", quietly = TRUE)) {
 }
 # nolint end
 
-sample <- readRDS(system.file("extdata/seurat_dataset_example.rds", package = "SCpubr"))
-
-if (isTRUE(getOption("SCpubr.v5"))){
-  suppressWarnings(sample[["SCT"]] <- as(object = sample[["SCT"]], Class = "Assay5"))
+if (requireNamespace("Seurat", quietly = TRUE)) {
+  sample <- readRDS(system.file("extdata/seurat_dataset_example.rds", package = "SCpubr"))
+  sample@assays$SCT$counts <- sample@assays$SCT$data
+  
+  if (isTRUE(getOption("SCpubr.v5"))){
+    suppressWarnings(sample[["SCT"]] <- as(object = sample[["SCT"]], Class = "Assay5"))
+  }
 }
 
+
 metacell_mapping <- readRDS(system.file("extdata/metacell_mapping_example.rds", package = "SCpubr"))
 infercnv_object <- readRDS(system.file("extdata/infercnv_object_example.rds", package = "SCpubr"))
 infercnv_object_metacells <- readRDS(system.file("extdata/infercnv_object_metacells_example.rds", package = "SCpubr"))
@@ -60,41 +64,11 @@ for (func in names(dependencies)){
   }
   dep_check[[func]] <- value
 }
+liana_output <- readRDS(system.file("extdata/liana_output_example.rds", package = "SCpubr"))
+
 
-# nolint start
-if (base::isFALSE(dep_check[["do_GroupedGOTermPlot"]]) | base::isFALSE(dep_check[["do_FunctionalAnnotationPlot"]])){
-  if (requireNamespace("org.Hs.eg.db", quietly = TRUE)) {
-    suppressMessages(library("org.Hs.eg.db"))
-  }
 
-  if (requireNamespace("AnnotationDbi", quietly = TRUE)) {
-    suppressMessages(library("AnnotationDbi"))
-    org.db <- AnnotationDbi::loadDb(system.file("./extdata/org.Hs.eg.sqlite", package = "org.Hs.eg.db"))
-  }
-}
-# nolint end
 
-# Remove this for publication in CRAN.
-# if (base::isFALSE(dep_check[["do_LigandReceptorPlot"]])){
-#   liana_output <- readRDS(system.file("extdata/liana_output_example.rds", package = "SCpubr"))
-# }
-# 
-# if (base::isFALSE(dep_check[["do_DimPlot"]]) &
-#     base::isFALSE(dep_check[["do_CorrelationPlot"]]) &
-#     base::isFALSE(dep_check[["do_ChordDiagramPlot"]]) &
-#     isTRUE(requireNamespace(pkg, quietly = TRUE)) &
-#     base::isFALSE(dep_check[["save_Plot"]])){
-#   p <- SCpubr::do_DimPlot(sample)
-#   data <- data.frame("A" = stats::runif(n = 10),
-#                      "B" = stats::runif(n = 10),
-#                      "C" = stats::runif(n = 10),
-#                      "D" = stats::runif(n = 10))
-#   data <- as.matrix(data)
-#   p.pheatmap <- pheatmap::pheatmap(data, cluster_rows = FALSE, cluster_cols = FALSE)
-#   p.heatmap <- ComplexHeatmap::Heatmap(data, cluster_rows = FALSE, cluster_columns = FALSE)
-#   p.chord <- SCpubr::do_ChordDiagramPlot(sample = sample, from = "seurat_clusters", to = "orig.ident")
-#   figure_path <- getwd()
-# }
 
 
 #monocle_sample <- sample
