@@ -6,7 +6,7 @@ if (base::isFALSE(dep_check[["do_AlluvialPlot"]])){
                                  first_group = "orig.ident",
                                  last_group = "seurat_clusters")
 
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
 
@@ -18,7 +18,59 @@ if (base::isFALSE(dep_check[["do_AlluvialPlot"]])){
                                  middle_groups = "annotation",
                                  last_group = "seurat_clusters")
 
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
+    p <- SCpubr::do_AlluvialPlot(sample,
+                                 first_group = "orig.ident",
+                                 middle_groups = "annotation",
+                                 last_group = "seurat_clusters",
+                                 use_labels = TRUE,
+                                 repel = TRUE)
+    
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
+    p <- SCpubr::do_AlluvialPlot(sample,
+                                 first_group = "orig.ident",
+                                 middle_groups = "annotation",
+                                 last_group = "seurat_clusters",
+                                 use_labels = TRUE,
+                                 repel = FALSE)
+    
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
+    p <- SCpubr::do_AlluvialPlot(sample,
+                                 first_group = "orig.ident",
+                                 middle_groups = "annotation",
+                                 last_group = "seurat_clusters",
+                                 flip = FALSE)
+    
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
+    p <- SCpubr::do_AlluvialPlot(sample,
+                                 first_group = "orig.ident",
+                                 middle_groups = "annotation",
+                                 last_group = "seurat_clusters",
+                                 flip = TRUE)
+    
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
+    p <- SCpubr::do_AlluvialPlot(sample,
+                                 first_group = "orig.ident",
+                                 middle_groups = "annotation",
+                                 last_group = "seurat_clusters",
+                                 use_viridis = TRUE,
+                                 colors.use = NULL)
+    
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
+    p <- SCpubr::do_AlluvialPlot(sample,
+                                 first_group = "orig.ident",
+                                 middle_groups = "annotation",
+                                 last_group = "seurat_clusters",
+                                 use_labels = FALSE,
+                                 repel = TRUE)
+    
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_AlluvialPlot(sample,
                                  first_group = "orig.ident",
@@ -26,7 +78,7 @@ if (base::isFALSE(dep_check[["do_AlluvialPlot"]])){
                                  last_group = "seurat_clusters",
                                  flip = TRUE)
 
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_AlluvialPlot(sample,
                                  first_group = "orig.ident",
@@ -36,7 +88,7 @@ if (base::isFALSE(dep_check[["do_AlluvialPlot"]])){
                                  use_labels = TRUE,
                                  repel = TRUE)
 
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_AlluvialPlot(sample,
                                  first_group = "orig.ident",
@@ -46,7 +98,7 @@ if (base::isFALSE(dep_check[["do_AlluvialPlot"]])){
                                  use_labels = TRUE,
                                  repel = FALSE)
 
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_AlluvialPlot(sample,
                                  first_group = "orig.ident",
@@ -56,7 +108,7 @@ if (base::isFALSE(dep_check[["do_AlluvialPlot"]])){
                                  use_labels = FALSE,
                                  repel = TRUE)
 
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_AlluvialPlot(sample,
                                  first_group = "orig.ident",
@@ -66,7 +118,7 @@ if (base::isFALSE(dep_check[["do_AlluvialPlot"]])){
                                  use_labels = FALSE,
                                  repel = FALSE)
 
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
 
@@ -79,7 +131,7 @@ if (base::isFALSE(dep_check[["do_AlluvialPlot"]])){
                                  middle_groups = "annotation",
                                  last_group = "seurat_clusters")
 
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     sample$orig.ident <- as.character(sample$orig.ident)
     sample$seurat_clusters <- as.character(sample$seurat_clusters)
@@ -89,7 +141,7 @@ if (base::isFALSE(dep_check[["do_AlluvialPlot"]])){
                                  middle_groups = "annotation",
                                  last_group = "seurat_clusters")
 
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_AlluvialPlot: geom_flow", {
@@ -99,7 +151,7 @@ if (base::isFALSE(dep_check[["do_AlluvialPlot"]])){
                                  last_group = "seurat_clusters",
                                  use_geom_flow = TRUE)
 
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_AlluvialPlot(sample,
                                  first_group = "orig.ident",
@@ -107,7 +159,7 @@ if (base::isFALSE(dep_check[["do_AlluvialPlot"]])){
                                  last_group = "seurat_clusters",
                                  use_geom_flow = FALSE)
 
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
   })
 
@@ -119,7 +171,7 @@ if (base::isFALSE(dep_check[["do_AlluvialPlot"]])){
                                  use_geom_flow = FALSE,
                                  stratum.fill.conditional = FALSE)
 
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_AlluvialPlot(sample,
                                  first_group = "orig.ident",
@@ -128,7 +180,7 @@ if (base::isFALSE(dep_check[["do_AlluvialPlot"]])){
                                  use_geom_flow = FALSE,
                                  stratum.fill.conditional = TRUE)
 
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
   })
 
@@ -139,7 +191,7 @@ if (base::isFALSE(dep_check[["do_AlluvialPlot"]])){
                                  last_group = "seurat_clusters",
                                  use_viridis = TRUE)
 
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_AlluvialPlot(sample,
                                  first_group = "orig.ident",
@@ -148,7 +200,7 @@ if (base::isFALSE(dep_check[["do_AlluvialPlot"]])){
                                  use_geom_flow = FALSE,
                                  use_viridis = TRUE)
 
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
   })
 
@@ -158,7 +210,7 @@ if (base::isFALSE(dep_check[["do_AlluvialPlot"]])){
                                  last_group = "orig.ident",
                                  colors.use = c("Cell" = "blue"))
 
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_AlluvialPlot: test_numbers", {
@@ -177,7 +229,7 @@ if (base::isFALSE(dep_check[["do_AlluvialPlot"]])){
                                  last_group = "seurat_clusters",
                                  use_viridis = TRUE)
 
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_AlluvialPlot(sample,
                                  first_group = "orig.ident",
@@ -187,7 +239,7 @@ if (base::isFALSE(dep_check[["do_AlluvialPlot"]])){
                                  last_group = "seurat_clusters",
                                  use_viridis = TRUE)
 
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_AlluvialPlot(sample,
                                  first_group = "orig.ident",
@@ -198,7 +250,7 @@ if (base::isFALSE(dep_check[["do_AlluvialPlot"]])){
                                  last_group = "seurat_clusters",
                                  use_viridis = TRUE)
 
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_AlluvialPlot(sample,
                                  first_group = "orig.ident",
@@ -210,7 +262,7 @@ if (base::isFALSE(dep_check[["do_AlluvialPlot"]])){
                                  last_group = "seurat_clusters",
                                  use_viridis = TRUE)
 
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_AlluvialPlot(sample,
                                  first_group = "orig.ident",
@@ -223,7 +275,7 @@ if (base::isFALSE(dep_check[["do_AlluvialPlot"]])){
                                  last_group = "seurat_clusters",
                                  use_viridis = TRUE)
 
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_AlluvialPlot(sample,
                                  first_group = "orig.ident",
@@ -237,7 +289,7 @@ if (base::isFALSE(dep_check[["do_AlluvialPlot"]])){
                                  last_group = "seurat_clusters",
                                  use_viridis = TRUE)
 
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_AlluvialPlot(sample,
                                  first_group = "orig.ident",
@@ -252,7 +304,7 @@ if (base::isFALSE(dep_check[["do_AlluvialPlot"]])){
                                  last_group = "seurat_clusters",
                                  use_viridis = TRUE)
 
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
   })
 }
