@@ -7,12 +7,12 @@ if (base::isFALSE(dep_check[["do_ChordDiagramPlot"]])){
     p <- SCpubr::do_ChordDiagramPlot(sample = sample,
                                      from = "seurat_clusters",
                                      to = "orig.ident")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(inherits(p, "recordedplot"))
 
     p <- SCpubr::do_ChordDiagramPlot(sample = sample,
                                      from = "seurat_clusters_char",
                                      to = "orig.ident_char")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(inherits(p, "recordedplot"))
   })
 
   testthat::test_that("do_ChordDiagramPlot: PASS - default", {
@@ -25,23 +25,14 @@ if (base::isFALSE(dep_check[["do_ChordDiagramPlot"]])){
                                      from = "seurat_clusters",
                                      to = "orig.ident",
                                      z_index = TRUE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(inherits(p, "recordedplot"))
 
     p <- SCpubr::do_ChordDiagramPlot(sample = sample,
                                      from = "seurat_clusters_char",
                                      to = "orig.ident_char",
                                      z_index = FALSE)
-    testthat::expect_type(p, "list")
-    
-    # # From df.
-    # liana_output <- readRDS(system.file("extdata/liana_output_example.rds", package = "SCpubr"))
-    # out <- SCpubr::do_LigandReceptorPlot(liana_output = liana_output, return_interactions = TRUE)
-    # 
-    # p <- SCpubr::do_ChordDiagramPlot(from_df = TRUE, 
-    #                                  df = out$`Group Interactions`, 
-    #                                  link.border.color = "black", 
-    #                                  z_index = TRUE)
-    # testthat::expect_type(p, "list")
+    testthat::expect_true(inherits(p, "recordedplot"))
+
   })
 
 
@@ -55,85 +46,85 @@ if (base::isFALSE(dep_check[["do_ChordDiagramPlot"]])){
     p <- SCpubr::do_ChordDiagramPlot(sample = sample,
                                      from = "orig.ident",
                                      to = "seurat_clusters")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(inherits(p, "recordedplot"))
 
     p <- SCpubr::do_ChordDiagramPlot(sample = sample,
                                      from = "orig.ident_char",
                                      to = "seurat_clusters_char")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(inherits(p, "recordedplot"))
 
     p <- SCpubr::do_ChordDiagramPlot(sample = sample,
                                      from = "orig.ident_char",
                                      to = "seurat_clusters")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(inherits(p, "recordedplot"))
 
     p <- SCpubr::do_ChordDiagramPlot(sample = sample,
                                      from = "orig.ident",
                                      to = "seurat_clusters_char")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(inherits(p, "recordedplot"))
 
     p <- SCpubr::do_ChordDiagramPlot(sample = sample,
                                      from = "orig.ident",
                                      to = "seurat_clusters",
                                      colors.from = c("Cell" = "blue"))
-    testthat::expect_type(p, "list")
+    testthat::expect_true(inherits(p, "recordedplot"))
 
     p <- SCpubr::do_ChordDiagramPlot(sample = sample,
                                      from = "orig.ident_char",
                                      to = "seurat_clusters",
                                      colors.from = c("Cell" = "blue"))
-    testthat::expect_type(p, "list")
+    testthat::expect_true(inherits(p, "recordedplot"))
 
     p <- SCpubr::do_ChordDiagramPlot(sample = sample,
                                      from = "orig.ident",
                                      to = "seurat_clusters")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(inherits(p, "recordedplot"))
 
     p <- SCpubr::do_ChordDiagramPlot(sample = sample,
                                      from = "orig.ident_char",
                                      to = "seurat_clusters")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(inherits(p, "recordedplot"))
 
     p <- SCpubr::do_ChordDiagramPlot(sample = sample,
                                      from = "seurat_clusters",
                                      to = "orig.ident",
                                      colors.to = c("Cell" = "blue"))
-    testthat::expect_type(p, "list")
+    testthat::expect_true(inherits(p, "recordedplot"))
 
     p <- SCpubr::do_ChordDiagramPlot(sample = sample,
                                      from = "seurat_clusters",
                                      to = "orig.ident_char",
                                      colors.to = c("Cell" = "blue"))
-    testthat::expect_type(p, "list")
+    testthat::expect_true(inherits(p, "recordedplot"))
 
     p <- SCpubr::do_ChordDiagramPlot(sample = sample,
                                      from = "seurat_clusters",
                                      to = "orig.ident")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(inherits(p, "recordedplot"))
 
     p <- SCpubr::do_ChordDiagramPlot(sample = sample,
                                      from = "seurat_clusters",
                                      to = "orig.ident_char")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(inherits(p, "recordedplot"))
 
     p <- SCpubr::do_ChordDiagramPlot(sample = sample,
                                      from = "orig.ident",
                                      to = "seurat_clusters",
                                      colors.from = c("Cell" = "#345211"))
-    testthat::expect_type(p, "list")
+    testthat::expect_true(inherits(p, "recordedplot"))
 
     p <- SCpubr::do_ChordDiagramPlot(sample = sample,
                                      from = "orig.ident",
                                      to = "seurat_clusters",
                                      colors.from = c("Cell" = "#345211FF"))
-    testthat::expect_type(p, "list")
+    testthat::expect_true(inherits(p, "recordedplot"))
 
     p <- SCpubr::do_ChordDiagramPlot(sample = sample,
                                      from = "orig.ident",
                                      to = "seurat_clusters",
                                      colors.from = c("Cell" = "#345211FF"),
                                      highlight_group = "Cell")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(inherits(p, "recordedplot"))
 
     sample$orig.ident <- ifelse(sample$seurat_clusters == "0", "A", "B")
     p <- SCpubr::do_ChordDiagramPlot(sample = sample,
@@ -141,7 +132,7 @@ if (base::isFALSE(dep_check[["do_ChordDiagramPlot"]])){
                                      to = "seurat_clusters",
                                      colors.from = c("A" = "#345211", "B" = "#345222"),
                                      highlight_group = "A")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(inherits(p, "recordedplot"))
 
   })
 
@@ -153,7 +144,7 @@ if (base::isFALSE(dep_check[["do_ChordDiagramPlot"]])){
                                      from = "seurat_clusters",
                                      to = "orig.ident",
                                      link.border.color = "black")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(inherits(p, "recordedplot"))
   })
 
   testthat::test_that("do_ChordDiagramPlot: PASS - alignment", {
@@ -164,13 +155,13 @@ if (base::isFALSE(dep_check[["do_ChordDiagramPlot"]])){
                                      from = "seurat_clusters",
                                      to = "orig.ident",
                                      alignment = "vertical")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(inherits(p, "recordedplot"))
 
     p <- SCpubr::do_ChordDiagramPlot(sample = sample,
                                      from = "seurat_clusters",
                                      to = "orig.ident",
                                      alignment = "horizontal")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(inherits(p, "recordedplot"))
   })
 
   testthat::test_that("do_ChordDiagramPlot: PASS - highlight group", {
@@ -181,7 +172,7 @@ if (base::isFALSE(dep_check[["do_ChordDiagramPlot"]])){
                                      from = "seurat_clusters",
                                      to = "orig.ident",
                                      highlight_group = "0")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(inherits(p, "recordedplot"))
   })
 
   testthat::test_that("do_ChordDiagramPlot: FAILS", {
