@@ -2,17 +2,17 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
   testthat::test_that("do_DimPlot: CRAN essentials", {
     p <- SCpubr::do_DimPlot(sample = sample)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample, idents.highlight = "0")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample, split.by = "seurat_clusters")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     sample$orig.ident <- sample(c("A", "B"), ncol(sample), replace = TRUE)
     p <- SCpubr::do_DimPlot(sample = sample, group.by = "seurat_clusters", split.by = "orig.ident")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - sample", {
@@ -20,7 +20,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
 
     p <- SCpubr::do_DimPlot(sample = sample)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - contour", {
@@ -29,24 +29,24 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             plot_density_contour = TRUE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             plot_density_contour = TRUE,
                             contour.position = "bottom")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             plot_density_contour = TRUE,
                             contour.position = "top")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             group.by = "seurat_clusters",
                             split.by = "annotation",
                             raster = TRUE,
                             plot_density_contour = TRUE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             group.by = "seurat_clusters",
@@ -54,7 +54,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
                             raster = TRUE,
                             plot_density_contour = TRUE,
                             contour.position = "top")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             group.by = "seurat_clusters",
@@ -62,7 +62,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
                             raster = TRUE,
                             label = TRUE,
                             plot_density_contour = TRUE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             group.by = "seurat_clusters",
@@ -71,27 +71,27 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
                             label = TRUE,
                             plot_density_contour = TRUE,
                             contour.position = "top")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             split.by = "annotation",
                             raster = TRUE,
                             plot_density_contour = TRUE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             split.by = "annotation",
                             raster = TRUE,
                             plot_density_contour = TRUE,
                             contour.position = "top")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             split.by = "annotation",
                             raster = TRUE,
                             label = TRUE,
                             plot_density_contour = TRUE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             split.by = "annotation",
@@ -99,27 +99,27 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
                             label = TRUE,
                             plot_density_contour = TRUE,
                             contour.position = "top")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             idents.highlight = "0",
                             raster = TRUE,
                             plot_density_contour = TRUE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             idents.highlight = "0",
                             raster = TRUE,
                             plot_density_contour = TRUE,
                             contour.position = "top")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             idents.highlight = "0",
                             raster = TRUE,
                             label = TRUE,
                             plot_density_contour = TRUE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             idents.highlight = "0",
@@ -127,7 +127,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
                             label = TRUE,
                             plot_density_contour = TRUE,
                             contour.position = "top")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - group.by + split.by", {
@@ -137,33 +137,33 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
     p <- SCpubr::do_DimPlot(sample = sample,
                             group.by = "seurat_clusters",
                             split.by = "annotation")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             group.by = "seurat_clusters",
                             split.by = "annotation",
                             label = TRUE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             group.by = "seurat_clusters",
                             split.by = "annotation",
                             raster = TRUE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             group.by = "seurat_clusters",
                             split.by = "annotation",
                             raster = TRUE,
                             label = TRUE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             group.by = "seurat_clusters",
                             split.by = "annotation",
                             raster = TRUE,
                             label = TRUE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - plot axis", {
@@ -172,19 +172,19 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
 
     p <- SCpubr::do_DimPlot(sample = sample, plot.axes = TRUE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample, reduction = "pca", plot.axes = TRUE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample, dims = c(2, 1), plot.axes = TRUE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     sample@reductions$diffusion <- sample@reductions$umap
     p <- SCpubr::do_DimPlot(sample = sample,
                             reduction = "diffusion",
                             plot.axes = TRUE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - sample cell_borders", {
@@ -193,17 +193,17 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
 
     p <- SCpubr::do_DimPlot(sample = sample, plot_cell_borders = TRUE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
     p <- SCpubr::do_DimPlot(sample = sample, plot_cell_borders = TRUE, raster = TRUE, pt.size = 1)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
     p <- SCpubr::do_DimPlot(sample = sample, plot_cell_borders = TRUE, idents.highlight = "1")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
     p <- SCpubr::do_DimPlot(sample = sample, plot_cell_borders = TRUE, raster = TRUE, idents.highlight = "1", pt.size = 1)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
     p <- SCpubr::do_DimPlot(sample = sample, plot_cell_borders = TRUE, split.by = "seurat_clusters")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
     p <- SCpubr::do_DimPlot(sample = sample, plot_cell_borders = TRUE, raster = TRUE, split.by = "seurat_clusters", pt.size = 1)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - sample marginal", {
@@ -215,31 +215,31 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
                             plot_marginal_distributions = TRUE,
                             marginal.type = "density",
                             plot_cell_borders = FALSE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             plot_marginal_distributions = TRUE,
                             marginal.type = "histogram",
                             plot_cell_borders = FALSE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- suppressWarnings({SCpubr::do_DimPlot(sample = sample,
                                               plot_marginal_distributions = TRUE,
                                               plot_cell_borders = FALSE,
                                               marginal.type = "violin")})
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             plot_marginal_distributions = TRUE,
                             marginal.type = "boxplot",
                             plot_cell_borders = FALSE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     #p <- SCpubr::do_DimPlot(sample = sample,
     #                        plot_marginal_distributions = TRUE,
     #                        marginal.type = "densigram",
     #                        plot_cell_borders = FALSE)
-    #testthat::expect_type(p, "list")
+    #testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - sample marginal size", {
@@ -250,7 +250,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
                             plot_marginal_distributions = TRUE,
                             marginal.size = 9,
                             plot_cell_borders = FALSE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - sample marginal group", {
@@ -261,7 +261,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
                             plot_marginal_distributions = TRUE,
                             marginal.group = FALSE,
                             plot_cell_borders = FALSE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: FAIL - sample marginal wrong marginal.type", {
@@ -300,7 +300,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             plot.title = "My awesome SC data set")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - subtitle", {
@@ -309,7 +309,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             plot.subtitle = "My awesome SC data set")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - caption", {
@@ -318,7 +318,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             plot.caption = "My awesome SC data set")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - sample + group.by", {
@@ -326,7 +326,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
 
     p <- SCpubr::do_DimPlot(sample = sample, group.by = "seurat_clusters")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - sample + split.by", {
@@ -334,7 +334,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
     testthat::skip_on_cran()
 
     p <- SCpubr::do_DimPlot(sample = sample, split.by = "seurat_clusters")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - sample + split.by + idents.keep", {
@@ -342,10 +342,10 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
 
     p <- SCpubr::do_DimPlot(sample = sample, split.by = "seurat_clusters", idents.keep = c("1", "3", "5"))
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample, split.by = "seurat_clusters", group.by = "annotation", idents.keep = c("1", "3", "5"))
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - dims", {
@@ -353,7 +353,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
 
     p <- SCpubr::do_DimPlot(sample = sample, dims = c(1, 2))
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - legend.position", {
@@ -361,7 +361,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
 
     p <- SCpubr::do_DimPlot(sample = sample, legend.position = "top")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - legend.ncol", {
@@ -369,7 +369,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
 
     p <- SCpubr::do_DimPlot(sample = sample, legend.ncol = 2)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - legend.nrow", {
@@ -377,7 +377,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
 
     p <- SCpubr::do_DimPlot(sample = sample, legend.nrow = 2)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - label", {
@@ -385,7 +385,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
 
     p <- SCpubr::do_DimPlot(sample = sample, label = TRUE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - order", {
@@ -393,7 +393,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
 
     p <- SCpubr::do_DimPlot(sample = sample, order = "5", shuffle = FALSE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - colors.use", {
@@ -412,12 +412,12 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
     p <- SCpubr::do_DimPlot(sample = sample, colors.use = c("Cell" = "#001219"),
                             split.by = "orig.ident")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DimPlot(sample = sample, colors.use = c("Cell" = "#001219"),
                             group.by = "orig.ident",
                             split.by = "seurat_clusters")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - cells.highlight", {
@@ -425,7 +425,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
 
     p <- SCpubr::do_DimPlot(sample = sample, cells.highlight = sample(colnames(sample), 50))
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - idents.highlight", {
@@ -433,7 +433,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
 
     p <- SCpubr::do_DimPlot(sample = sample, idents.highlight = "5")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - cells.highlight and idents.highlight", {
@@ -441,7 +441,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
 
     p <- SCpubr::do_DimPlot(sample = sample, cells.highlight = sample(colnames(sample), 50), idents.highlight = "2")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - idents.keep", {
@@ -449,7 +449,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
 
     p <- SCpubr::do_DimPlot(sample = sample, idents.keep = "5")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: FAIL - group.by and cells.highlights used", {
@@ -502,7 +502,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
 
     p <- SCpubr::do_DimPlot(sample = sample, group.by = "seurat_clusters", colors.use = colors)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - split.by + colors", {
@@ -510,7 +510,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
 
     p <- SCpubr::do_DimPlot(sample = sample, split.by = "seurat_clusters", colors.use = colors)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: FAIL - more than 1 color with cells highlight", {
@@ -550,7 +550,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
                             plot.title = "Plot title",
                             plot.subtitle = "Plot subtitle",
                             plot.caption = "Plot caption")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - legend.position none", {
@@ -559,7 +559,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             legend.position = "none")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - dims different", {
@@ -568,7 +568,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
     p <- SCpubr::do_DimPlot(sample = sample,
                             dims = c(2, 1))
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - diffusion maps", {
@@ -578,7 +578,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
     sample@reductions$diffusion <- sample@reductions$umap
     p <- SCpubr::do_DimPlot(sample = sample,
                             reduction = "diffusion")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - group.by + idents.keep", {
@@ -588,7 +588,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
     p <- SCpubr::do_DimPlot(sample = sample,
                             group.by = "seurat_clusters",
                             idents.keep = "4")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
 
@@ -598,7 +598,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
     sample$seurat_clusters <- factor(sample$seurat_clusters)
     p <- SCpubr::do_DimPlot(sample = sample, split.by = "seurat_clusters", colors.use = colors)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: PASS - split.by + factor + idents.keep", {
@@ -607,7 +607,7 @@ if (base::isFALSE(dep_check[["do_DimPlot"]])){
 
     sample$seurat_clusters <- factor(sample$seurat_clusters)
     p <- SCpubr::do_DimPlot(sample = sample, split.by = "seurat_clusters", colors.use = colors, idents.keep = "4")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DimPlot: FAIL - wrong font.type", {
