@@ -4,12 +4,8 @@ if (isFALSE(dep_check[["do_DotPlot"]])){
 
     p <- SCpubr::do_DotPlot(sample = sample,
                             features = "EPC1")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
-    p <- SCpubr::do_DotPlot(sample = sample,
-                            features = "EPC1",
-                            dot_border = FALSE)
-    testthat::expect_type(p, "list")
   })
 
   testthat::test_that("do_DotPlot: PASS - one variable", {
@@ -18,59 +14,83 @@ if (isFALSE(dep_check[["do_DotPlot"]])){
 
     p <- SCpubr::do_DotPlot(sample = sample,
                             features = "EPC1")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
+    p <- SCpubr::do_DotPlot(sample = sample,
+                            features = "EPC1", flip = TRUE)
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
+    p <- SCpubr::do_DotPlot(sample = sample,
+                            features = "EPC1", flip = FALSE)
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
+    p <- SCpubr::do_DotPlot(sample = sample,
+                            features = "EPC1",
+                            max.cutoff = 0.5,
+                            min.cutoff = 0.4)
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
+    p <- SCpubr::do_DotPlot(sample = sample,
+                            features = "EPC1",
+                            zscore.data = TRUE)
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
+    p <- SCpubr::do_DotPlot(sample = sample,
+                            features = "EPC1",
+                            split.by = "annotation",
+                            flip = TRUE)
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
+    p <- SCpubr::do_DotPlot(sample = sample,
+                            features = "EPC1",
+                            split.by = "annotation",
+                            flip = FALSE)
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
+    
+    p <- SCpubr::do_DotPlot(sample = sample,
+                            features = "EPC1",
+                            zscore.data = TRUE)
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
+    p <- SCpubr::do_DotPlot(sample = sample,
+                            features = list("A" = "EPC1"),
+                            zscore.data = TRUE)
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
+    p <- SCpubr::do_DotPlot(sample = sample,
+                            features = list("A" = "EPC1"),
+                            zscore.data = TRUE)
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DotPlot(sample = sample,
                             features = "EPC1",
-                            dot_border = FALSE,
                             legend.position = "right")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
     
     p <- SCpubr::do_DotPlot(sample = sample,
                             features = "EPC1",
-                            dot_border = FALSE,
                             legend.position = "top")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
     
     p <- SCpubr::do_DotPlot(sample = sample,
                             features = "EPC1",
-                            dot_border = FALSE,
                             legend.position = "none")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
     
     p <- SCpubr::do_DotPlot(sample = sample,
                             features = "EPC1",
-                            dot_border = TRUE,
-                            legend.position = "none")
-    testthat::expect_type(p, "list")
-    
-    p <- SCpubr::do_DotPlot(sample = sample,
-                            features = "EPC1",
-                            dot_border = TRUE,
                             legend.position = "none",
                             use_viridis = FALSE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
     
     p <- SCpubr::do_DotPlot(sample = sample,
                             features = "EPC1",
-                            dot_border = TRUE,
                             legend.position = "none",
                             use_viridis = FALSE)
-    testthat::expect_type(p, "list")
-    
-    p <- SCpubr::do_DotPlot(sample = sample,
-                            features = "EPC1",
-                            dot_border = FALSE,
-                            legend.position = "none",
-                            use_viridis = FALSE)
-    testthat::expect_type(p, "list")
-    
-    p <- SCpubr::do_DotPlot(sample = sample,
-                            features = "EPC1",
-                            dot_border = FALSE,
-                            legend.position = "none",
-                            use_viridis = FALSE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DotPlot: PASS - plot grid", {
@@ -80,12 +100,12 @@ if (isFALSE(dep_check[["do_DotPlot"]])){
     p <- SCpubr::do_DotPlot(sample = sample,
                             features = "EPC1",
                             plot.grid = TRUE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_DotPlot(sample = sample,
                             features = "EPC1",
                             plot.grid = FALSE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DotPlot: PASS - use_viridis", {
@@ -94,15 +114,8 @@ if (isFALSE(dep_check[["do_DotPlot"]])){
 
     p <- SCpubr::do_DotPlot(sample = sample,
                             features = "EPC1",
-                            use_viridis = TRUE,
-                            dot_border = FALSE)
-    testthat::expect_type(p, "list")
-
-    p <- SCpubr::do_DotPlot(sample = sample,
-                            features = "EPC1",
-                            use_viridis = TRUE,
-                            dot_border = TRUE)
-    testthat::expect_type(p, "list")
+                            use_viridis = TRUE)
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DotPlot: PASS - one variable legend normal", {
@@ -112,7 +125,7 @@ if (isFALSE(dep_check[["do_DotPlot"]])){
     p <- SCpubr::do_DotPlot(sample = sample,
                             features = "EPC1",
                             legend.type = "normal")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DotPlot: PASS - one variable legend colorbar", {
@@ -122,7 +135,7 @@ if (isFALSE(dep_check[["do_DotPlot"]])){
     p <- SCpubr::do_DotPlot(sample = sample,
                             features = "EPC1",
                             legend.type = "colorbar")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
 
@@ -169,126 +182,45 @@ if (isFALSE(dep_check[["do_DotPlot"]])){
     p <- SCpubr::do_DotPlot(sample = sample,
                             features = "EPC1",
                             flip = TRUE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DotPlot: PASS - multiple features", {
     testthat::skip_on_cran()
+    
+    genes <- Seurat::VariableFeatures(sample)[1:10]
 
-
-    genes <- list("Naive CD4+ T" = Seurat::VariableFeatures(sample)[1:2],
-                  "EPC1+ Mono" = Seurat::VariableFeatures(sample)[3:4],
-                  "Memory CD4+" = Seurat::VariableFeatures(sample)[5],
-                  "B" = Seurat::VariableFeatures(sample)[6],
-                  "CD8+ T" = Seurat::VariableFeatures(sample)[7],
-                  "FCGR3A+ Mono" = Seurat::VariableFeatures(sample)[8:9],
-                  "NK" = Seurat::VariableFeatures(sample)[10:11],
-                  "DC" = Seurat::VariableFeatures(sample)[12:13],
-                  "Platelet" = Seurat::VariableFeatures(sample)[14])
-    genes <- unname(unlist(genes))
     p <- suppressWarnings({SCpubr::do_DotPlot(sample = sample,
                                               features = genes)})
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DotPlot: PASS - multiple features flip", {
     testthat::skip_on_cran()
 
 
-    genes <- list("Naive CD4+ T" = Seurat::VariableFeatures(sample)[1:2],
-                  "EPC1+ Mono" = Seurat::VariableFeatures(sample)[3:4],
-                  "Memory CD4+" = Seurat::VariableFeatures(sample)[5],
-                  "B" = Seurat::VariableFeatures(sample)[6],
-                  "CD8+ T" = Seurat::VariableFeatures(sample)[7],
-                  "FCGR3A+ Mono" = Seurat::VariableFeatures(sample)[8:9],
-                  "NK" = Seurat::VariableFeatures(sample)[10:11],
-                  "DC" = Seurat::VariableFeatures(sample)[12:13],
-                  "Platelet" = Seurat::VariableFeatures(sample)[14])
-    genes <- unname(unlist(genes))
+    genes <- Seurat::VariableFeatures(sample)[1:10]
+    
     p <- suppressWarnings({SCpubr::do_DotPlot(sample = sample,
                                               features = genes,
                                               flip = TRUE)})
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_DotPlot: PASS - multiple features flip rotate x labels", {
     testthat::skip_on_cran()
 
 
-    genes <- list("Naive CD4+ T" = Seurat::VariableFeatures(sample)[1:2],
-                  "EPC1+ Mono" = Seurat::VariableFeatures(sample)[3:4],
-                  "Memory CD4+" = Seurat::VariableFeatures(sample)[5],
-                  "B" = Seurat::VariableFeatures(sample)[6],
-                  "CD8+ T" = Seurat::VariableFeatures(sample)[7],
-                  "FCGR3A+ Mono" = Seurat::VariableFeatures(sample)[8:9],
-                  "NK" = Seurat::VariableFeatures(sample)[10:11],
-                  "DC" = Seurat::VariableFeatures(sample)[12:13],
-                  "Platelet" = Seurat::VariableFeatures(sample)[14])
-    genes <- unname(unlist(genes))
+    genes <- Seurat::VariableFeatures(sample)[1:10]
     p <- suppressWarnings({SCpubr::do_DotPlot(sample = sample,
                                               features = genes,
                                               flip = TRUE,
                                               axis.text.x.angle = 45)})
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
-  testthat::test_that("do_DotPlot: PASS - list of features", {
-    testthat::skip_on_cran()
 
 
-    genes <- list("Naive CD4+ T" = Seurat::VariableFeatures(sample)[1:2],
-                  "EPC1+ Mono" = Seurat::VariableFeatures(sample)[3:4],
-                  "Memory CD4+" = Seurat::VariableFeatures(sample)[5],
-                  "B" = Seurat::VariableFeatures(sample)[6],
-                  "CD8+ T" = Seurat::VariableFeatures(sample)[7],
-                  "FCGR3A+ Mono" = Seurat::VariableFeatures(sample)[8:9],
-                  "NK" = Seurat::VariableFeatures(sample)[10:11],
-                  "DC" = Seurat::VariableFeatures(sample)[12:13],
-                  "Platelet" = Seurat::VariableFeatures(sample)[14])
-    p <- suppressWarnings({SCpubr::do_DotPlot(sample = sample,
-                                              features = genes)})
-    testthat::expect_type(p, "list")
-  })
-
-  testthat::test_that("do_DotPlot: PASS - list of features cluster idents", {
-    testthat::skip_on_cran()
-
-
-    genes <- list("Naive CD4+ T" = Seurat::VariableFeatures(sample)[1:2],
-                  "EPC1+ Mono" = Seurat::VariableFeatures(sample)[3:4],
-                  "Memory CD4+" = Seurat::VariableFeatures(sample)[5],
-                  "B" = Seurat::VariableFeatures(sample)[6],
-                  "CD8+ T" = Seurat::VariableFeatures(sample)[7],
-                  "FCGR3A+ Mono" = Seurat::VariableFeatures(sample)[8:9],
-                  "NK" = Seurat::VariableFeatures(sample)[10:11],
-                  "DC" = Seurat::VariableFeatures(sample)[12:13],
-                  "Platelet" = Seurat::VariableFeatures(sample)[14])
-    p <- suppressWarnings({SCpubr::do_DotPlot(sample = sample,
-                                              features = genes,
-                                              cluster = TRUE)})
-    testthat::expect_type(p, "list")
-  })
-
-  testthat::test_that("do_DotPlot: PASS - list of features cluster idents modify colors", {
-    testthat::skip_on_cran()
-
-
-    genes <- list("Naive CD4+ T" = Seurat::VariableFeatures(sample)[1:2],
-                  "EPC1+ Mono" = Seurat::VariableFeatures(sample)[3:4],
-                  "Memory CD4+" = Seurat::VariableFeatures(sample)[5],
-                  "B" = Seurat::VariableFeatures(sample)[6],
-                  "CD8+ T" = Seurat::VariableFeatures(sample)[7],
-                  "FCGR3A+ Mono" = Seurat::VariableFeatures(sample)[8:9],
-                  "NK" = Seurat::VariableFeatures(sample)[10:11],
-                  "DC" = Seurat::VariableFeatures(sample)[12:13],
-                  "Platelet" = Seurat::VariableFeatures(sample)[14])
-    p <- suppressWarnings({SCpubr::do_DotPlot(sample = sample,
-                                              features = genes,
-                                              cluster = TRUE,
-                                              colors.use = c("#001219", "#e9d8a6"))})
-    testthat::expect_type(p, "list")
-  })
-
 
 
   testthat::test_that("do_DotPlot: PASS - one variable xlab, ylab, title, subtitle, caption", {
@@ -302,7 +234,7 @@ if (isFALSE(dep_check[["do_DotPlot"]])){
                             plot.title = "C",
                             plot.subtitle = "D",
                             plot.caption = "E")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 }
 
