@@ -4,133 +4,100 @@ if(base::isFALSE(dep_check[["do_RidgePlot"]])){
 
     p <- SCpubr::do_RidgePlot(sample = sample,
                               feature = "nCount_RNA")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_RidgePlot(sample = sample,
                               feature = "nCount_RNA",
                               continuous_scale = TRUE,
                               use_viridis = TRUE,
                               viridis.direction = 1)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
-    p <- SCpubr::do_RidgePlot(sample = sample,
-                              feature = "nFeature_RNA",
-                              continuous_scale = TRUE,
-                              compute_quantiles = TRUE,
-                              compute_distribution_tails = TRUE)
-    testthat::expect_type(p, "list")
 
-    p <- SCpubr::do_RidgePlot(sample = sample,
-                              feature = "nCount_RNA",
-                              continuous_scale = TRUE,
-                              compute_quantiles = TRUE,
-                              compute_distribution_tails = TRUE,
-                              prob_tails = 0.4)
-    testthat::expect_type(p, "list")
 
-    p <- SCpubr::do_RidgePlot(sample = sample,
-                              feature = "nFeature_RNA",
-                              continuous_scale = TRUE,
-                              compute_quantiles = TRUE,
-                              color_by_probabilities = TRUE)
-    testthat::expect_type(p, "list")
 
   })
 
   testthat::test_that("do_RidgePlot: PASS - default", {
     testthat::skip_on_cran()
+    
+    p <- SCpubr::do_RidgePlot(sample = sample,
+                              feature = "nCount_RNA",
+                              continuous_scale = FALSE)
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
+    p <- SCpubr::do_RidgePlot(sample = sample,
+                              feature = "nCount_RNA",
+                              continuous_scale = FALSE,
+                              group.by = "annotation",
+                              colors.use = c("A" = "red", "B" = "blue"))
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
+    p <- SCpubr::do_RidgePlot(sample = sample,
+                              feature = "nCount_RNA",
+                              split.by = "annotation",
+                              continuous_scale = TRUE,
+                              use_viridis = TRUE,
+                              viridis.direction = 1)
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
+    p <- SCpubr::do_RidgePlot(sample = sample,
+                              feature = "nCount_RNA",
+                              continuous_scale = TRUE,
+                              use_viridis = TRUE,
+                              viridis.direction = 1)
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
+    p <- SCpubr::do_RidgePlot(sample = sample,
+                              feature = "nCount_RNA",
+                              continuous_scale = TRUE,
+                              use_viridis = TRUE,
+                              viridis.direction = -1)
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
+    p <- SCpubr::do_RidgePlot(sample = sample,
+                              feature = "nCount_RNA",
+                              continuous_scale = TRUE,
+                              use_viridis = FALSE,
+                              sequential.direction = 1)
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
+    p <- SCpubr::do_RidgePlot(sample = sample,
+                              feature = "nCount_RNA",
+                              continuous_scale = TRUE,
+                              use_viridis = FALSE,
+                              sequential.direction = -1)
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
+
 
-    p <- SCpubr::do_RidgePlot(sample = sample,
-                              feature = "nCount_RNA",
-                              continuous_scale = TRUE,
-                              use_viridis = TRUE,
-                              viridis.direction = 1)
-    testthat::expect_type(p, "list")
-    
-    p <- SCpubr::do_RidgePlot(sample = sample,
-                              feature = "nCount_RNA",
-                              continuous_scale = TRUE,
-                              use_viridis = TRUE,
-                              viridis.direction = -1)
-    testthat::expect_type(p, "list")
-    
-    p <- SCpubr::do_RidgePlot(sample = sample,
-                              feature = "nCount_RNA",
-                              continuous_scale = TRUE,
-                              use_viridis = FALSE,
-                              sequential.direction = 1)
-    testthat::expect_type(p, "list")
-    
-    p <- SCpubr::do_RidgePlot(sample = sample,
-                              feature = "nCount_RNA",
-                              continuous_scale = TRUE,
-                              use_viridis = FALSE,
-                              sequential.direction = -1)
-    testthat::expect_type(p, "list")
-    
-    p <- SCpubr::do_RidgePlot(sample = sample,
-                              feature = "nFeature_RNA",
-                              continuous_scale = TRUE,
-                              compute_quantiles = TRUE,
-                              color_by_probabilities = TRUE,
-                              use_viridis = TRUE,
-                              viridis.direction = 1)
-    testthat::expect_type(p, "list")
-    
-    p <- SCpubr::do_RidgePlot(sample = sample,
-                              feature = "nFeature_RNA",
-                              continuous_scale = TRUE,
-                              compute_quantiles = TRUE,
-                              color_by_probabilities = TRUE,
-                              use_viridis = TRUE,
-                              viridis.direction = -1)
-    testthat::expect_type(p, "list")
-    
-    p <- SCpubr::do_RidgePlot(sample = sample,
-                              feature = "nFeature_RNA",
-                              continuous_scale = TRUE,
-                              compute_quantiles = TRUE,
-                              color_by_probabilities = TRUE,
-                              use_viridis = FALSE,
-                              sequential.direction = 1)
-    testthat::expect_type(p, "list")
-    
-    p <- SCpubr::do_RidgePlot(sample = sample,
-                              feature = "nFeature_RNA",
-                              continuous_scale = TRUE,
-                              compute_quantiles = TRUE,
-                              color_by_probabilities = TRUE,
-                              use_viridis = FALSE,
-                              sequential.direction = -1)
-    testthat::expect_type(p, "list")
-    
     p <- SCpubr::do_RidgePlot(sample = sample,
                               feature = "nCount_RNA")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_RidgePlot(sample = sample,
                               feature = "nCount_RNA",
                               group.by = "orig.ident")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     sample$orig.ident <- factor(sample$orig.ident)
 
     p <- SCpubr::do_RidgePlot(sample = sample,
                               feature = "nCount_RNA",
                               group.by = "orig.ident")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_RidgePlot(sample = sample,
                               feature = "nCount_RNA",
                               legend.position = "bottom")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_RidgePlot(sample = sample,
                               feature = "nCount_RNA",
                               group.by = "orig.ident",
                               legend.position = "bottom",
                               colors.use = c("Cell" = "red"))
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_RidgePlot: PASS - plot.grid", {
@@ -140,12 +107,24 @@ if(base::isFALSE(dep_check[["do_RidgePlot"]])){
     p <- SCpubr::do_RidgePlot(sample = sample,
                               feature = "nCount_RNA",
                               plot.grid = TRUE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
+    p <- SCpubr::do_RidgePlot(sample = sample,
+                              feature = "nCount_RNA",
+                              plot.grid = TRUE,
+                              flip = TRUE)
+    testthat::expect_true(ggplot2::is_ggplot(p))
+    
+    p <- SCpubr::do_RidgePlot(sample = sample,
+                              feature = "nCount_RNA",
+                              plot.grid = TRUE,
+                              flip = FALSE)
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_RidgePlot(sample = sample,
                               feature = "nCount_RNA",
                               plot.grid = FALSE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
 
@@ -156,7 +135,7 @@ if(base::isFALSE(dep_check[["do_RidgePlot"]])){
     p <- SCpubr::do_RidgePlot(sample = sample,
                               feature = "nCount_RNA",
                               split.by = "orig.ident")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_RidgePlot: PASS - continuous scale", {
@@ -167,13 +146,13 @@ if(base::isFALSE(dep_check[["do_RidgePlot"]])){
                               feature = "nCount_RNA",
                               continuous_scale = TRUE,
                               viridis.direction = 1)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_RidgePlot(sample = sample,
                               feature = "nCount_RNA",
                               continuous_scale = TRUE,
                               viridis.direction = -1)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
   testthat::test_that("do_RidgePlot: PASS - group.by", {
@@ -183,60 +162,11 @@ if(base::isFALSE(dep_check[["do_RidgePlot"]])){
     p <- SCpubr::do_RidgePlot(sample = sample,
                               feature = "nCount_RNA",
                               group.by = "orig.ident")
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 
-  testthat::test_that("do_RidgePlot: PASS - quantiles", {
-    testthat::skip_on_cran()
 
 
-    p <- SCpubr::do_RidgePlot(sample = sample,
-                              feature = "nCount_RNA",
-                              continuous_scale = TRUE,
-                              compute_custom_quantiles = TRUE,
-                              compute_quantiles = TRUE)
-    testthat::expect_type(p, "list")
-
-    p <- SCpubr::do_RidgePlot(sample = sample,
-                              feature = "nCount_RNA",
-                              continuous_scale = TRUE,
-                              compute_custom_quantiles = TRUE,
-                              compute_quantiles = TRUE,
-                              quantiles = c(0.1, 0.5, 0.9))
-    testthat::expect_type(p, "list")
-  })
-
-  testthat::test_that("do_RidgePlot: PASS - distribution tails", {
-    testthat::skip_on_cran()
-
-
-    p <- SCpubr::do_RidgePlot(sample = sample,
-                              feature = "nFeature_RNA",
-                              continuous_scale = TRUE,
-                              compute_quantiles = TRUE,
-                              compute_distribution_tails = TRUE)
-    testthat::expect_type(p, "list")
-
-    p <- SCpubr::do_RidgePlot(sample = sample,
-                              feature = "nCount_RNA",
-                              continuous_scale = TRUE,
-                              compute_quantiles = TRUE,
-                              compute_distribution_tails = TRUE,
-                              prob_tails = 0.4)
-    testthat::expect_type(p, "list")
-  })
-
-  testthat::test_that("do_RidgePlot: PASS - distribution tails", {
-    testthat::skip_on_cran()
-
-
-    p <- SCpubr::do_RidgePlot(sample = sample,
-                              feature = "nFeature_RNA",
-                              continuous_scale = TRUE,
-                              compute_quantiles = TRUE,
-                              color_by_probabilities = TRUE)
-    testthat::expect_type(p, "list")
-  })
 
   testthat::test_that("do_RidgePlot: PASS - flip", {
     testthat::skip_on_cran()
@@ -245,12 +175,12 @@ if(base::isFALSE(dep_check[["do_RidgePlot"]])){
     p <- SCpubr::do_RidgePlot(sample = sample,
                               feature = "nFeature_RNA",
                               flip = TRUE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
 
     p <- SCpubr::do_RidgePlot(sample = sample,
                               feature = "nFeature_RNA",
                               flip = FALSE)
-    testthat::expect_type(p, "list")
+    testthat::expect_true(ggplot2::is_ggplot(p))
   })
 }
 
